RunningStatistics

Struct RunningStatistics 

pub struct RunningStatistics<S>
where S: Dimension + RemoveAxis,
{ /* private fields */ }
A container to keep track of sufficient statistics of an arbitrary shape ndarray

Type parameters

  • S : The shape of the array

Implementations

Source

impl<S> RunningStatistics<S>
where S: Dimension + RemoveAxis,

pub fn new(shape: S) -> Self

Create a new RunningStatistics object

Arguments
  • shape - The shape of the array
Examples
use legume_numeric::matrix::ndarray_stat::RunningStatistics;
use ndarray::Ix1;
let nrow = 10;
RunningStatistics::new(Ix1(nrow));
pub fn add<V>(&mut self, xx: &ArrayBase<V, S>)
where V: Data<Elem = f32>,

pub fn add_element<I>(&mut self, idx: &I, val: f32)
where I: NdIndex<S> + Clone,

pub fn clear(&mut self)

pub fn count_positives(&self) -> ArrayBase<OwnedRepr<f32>, S>

Frequency of positive values. For a sparse count matrix, this will reflect the number of non-zero values

pub fn sum(&self) -> ArrayBase<OwnedRepr<f32>, S>

Sum of values

pub fn mean(&self) -> ArrayBase<OwnedRepr<f32>, S>

Average statistic

pub fn variance(&self) -> ArrayBase<OwnedRepr<f32>, S>

Variance

pub fn std(&self) -> ArrayBase<OwnedRepr<f32>, S>

Standard deviation

pub fn shape(&self) -> &[usize]

pub fn save( &self, filename: &str, names: &[Box<str>], sep: &str, row_column_name: Option<&str>, ) -> Result<()>

Save the statistics to a file

Arguments
  • filename - The name of the file to save the statistics to
  • names - The names of the statistics
  • sep - Separator for text formats
  • row_column_name - Name for the row column in parquet format (defaults to “stat”)
pub fn to_string_vec( &self, names: &[Box<str>], sep: &str, ) -> Result<Vec<Box<str>>>