pub struct RunningStatistics<S>where
S: Dimension + RemoveAxis,{ /* private fields */ }Expand description
A container to keep track of sufficient statistics of an arbitrary
shape ndarray
Type parameters
S: The shape of the array
Implementations
Sourceimpl<S> RunningStatistics<S>where
S: Dimension + RemoveAxis,
impl<S> RunningStatistics<S>where
S: Dimension + RemoveAxis,
pub fn add<V>(&mut self, xx: &ArrayBase<V, S>)
pub fn add_element<I>(&mut self, idx: &I, val: f32)
pub fn clear(&mut self)
Sourcepub fn count_positives(&self) -> ArrayBase<OwnedRepr<f32>, S>
pub fn count_positives(&self) -> ArrayBase<OwnedRepr<f32>, S>
Frequency of positive values. For a sparse count matrix, this will reflect the number of non-zero values
pub fn shape(&self) -> &[usize]
Sourcepub fn save(
&self,
filename: &str,
names: &[Box<str>],
sep: &str,
row_column_name: Option<&str>,
) -> Result<()>
pub fn save( &self, filename: &str, names: &[Box<str>], sep: &str, row_column_name: Option<&str>, ) -> Result<()>
Save the statistics to a file
Arguments
filename- The name of the file to save the statistics tonames- The names of the statisticssep- Separator for text formatsrow_column_name- Name for the row column in parquet format (defaults to “stat”)
pub fn to_string_vec( &self, names: &[Box<str>], sep: &str, ) -> Result<Vec<Box<str>>>